@@ -13,7 +13,7 @@ def calc_stats(t: tuple, inst_params: dict, params: dict, swap: bool,
                correction: str = None, gof_tr=None, max_size=None):
     alt, counts, rmsea = t
     res = list()
-    params = get_params_at_slice(params, alt)
+    params = get_params_at_slice(params, alt, clip_at_max_slice=False)
     if gof_tr is not None and not rmsea < gof_tr:
         params['r'] = alt
         if 'k' in params:
